EXPORTS
	?LibEntryL@@YAPAVCScriptBase@@AAVCTestModuleIf@@@Z @ 1 NONAME ; class CScriptBase * LibEntryL(class CTestModuleIf &)
	?AddObserverL@CCCAppCmsContactFetcherWrapper@@QAEXAAVMCCAppContactFieldDataObserver@@@Z @ 2 NONAME ; void CCCAppCmsContactFetcherWrapper::AddObserverL(class MCCAppContactFieldDataObserver &)
	?ContactFieldDataArray@CCCAppCmsContactFetcherWrapper@@QAEAAV?$RPointerArray@VCCmsContactField@@@@XZ @ 3 NONAME ; class RPointerArray<class CCmsContactField> & CCCAppCmsContactFetcherWrapper::ContactFieldDataArray(void)
	?ContactIdentifierLC@CCCAppCmsContactFetcherWrapper@@QAEPAVHBufC8@@XZ @ 4 NONAME ; class HBufC8 * CCCAppCmsContactFetcherWrapper::ContactIdentifierLC(void)
	?ContactInfo@CCCAppCmsContactFetcherWrapper@@QAEPBVCCmsContactFieldInfo@@XZ @ 5 NONAME ; class CCmsContactFieldInfo const * CCCAppCmsContactFetcherWrapper::ContactInfo(void)
	?ContactStore@CCCAppCmsContactFetcherWrapper@@QBE?AW4TCmsContactStore@@XZ @ 6 NONAME ; enum TCmsContactStore CCCAppCmsContactFetcherWrapper::ContactStore(void) const
	?CreateInstanceL@CCCAppCmsContactFetcherWrapper@@SAPAV1@PAVCCCAParameter@@W4TWrapperParam@1@@Z @ 7 NONAME ; class CCCAppCmsContactFetcherWrapper * CCCAppCmsContactFetcherWrapper::CreateInstanceL(class CCCAParameter *, enum CCCAppCmsContactFetcherWrapper::TWrapperParam)
	?GetContactActionFieldCount@CCCAppCmsContactFetcherWrapper@@QAEHW4TVPbkContactActionTypeSelector@VPbkFieldTypeSelectorFactory@@@Z @ 8 NONAME ; int CCCAppCmsContactFetcherWrapper::GetContactActionFieldCount(enum VPbkFieldTypeSelectorFactory::TVPbkContactActionTypeSelector)
	?InstanceL@CCCAppCmsContactFetcherWrapper@@SAPAV1@XZ @ 9 NONAME ; class CCCAppCmsContactFetcherWrapper * CCCAppCmsContactFetcherWrapper::InstanceL(void)
	?IsServiceAvailable@CCCAppCmsContactFetcherWrapper@@QAEHW4TVPbkContactActionTypeSelector@VPbkFieldTypeSelectorFactory@@@Z @ 10 NONAME ; int CCCAppCmsContactFetcherWrapper::IsServiceAvailable(enum VPbkFieldTypeSelectorFactory::TVPbkContactActionTypeSelector)
	?Release@CCCAppCmsContactFetcherWrapper@@QAEXXZ @ 11 NONAME ; void CCCAppCmsContactFetcherWrapper::Release(void)
	?RemoveObserver@CCCAppCmsContactFetcherWrapper@@QAEXAAVMCCAppContactFieldDataObserver@@@Z @ 12 NONAME ; void CCCAppCmsContactFetcherWrapper::RemoveObserver(class MCCAppContactFieldDataObserver &)

